@@ -3,9 +3,12 @@ from django.core.exceptions import ImproperlyConfigured
 
 SETTINGS_TYPES = {
     "MARKDOWN_VIEW_LOADERS": list,
+    "MARKDOWN_VIEW_LOADER_TEMPLATES_DIR": str,
     "MARKDOWN_VIEW_EXTENSIONS": list,
     "MARKDOWN_VIEW_BASE_DIR": str,
     "MARKDOWN_VIEW_TEMPLATE": str,
+    "MARKDOWN_VIEW_TEMPLATE_USE_TOC": bool,
+    "MARKDOWN_VIEW_TEMPLATE_USE_HIGHLIGHT_JS": bool,
     "MARKDOWN_VIEW_USE_REQUEST_CONTEXT": bool,
     "MARKDOWN_VIEW_EXTRA_CONTEXT": dict
 }
